@@ -144,7 +144,7 @@ def ext_scan_heads(mf, data_form):
                 "[ERROR] Primer not located properly, exiting NOW!")
         while cont:
             try:
-                while mf.read(4)[3] == 0x80:
+                while mf.read(4)[3] >= 0x80:
                     continue
             except IndexError:
                 break
@@ -153,7 +153,7 @@ def ext_scan_heads(mf, data_form):
             mf.seek(-4, 1)
             datas = mf.read(8)
             mf.seek(-8, 1)
-            if datas[7] == 0x80:
+            if datas[7] >= 0x80:
                 mf.seek(4,1)
                 continue
             elif (datas[:4] != unhexlify("00000000")) or not headers.primers:
@@ -326,10 +326,10 @@ def load_raw(raw_file,
 if __name__ == "__main__":
     logging.basicConfig()
     logger.setLevel("DEBUG")
-    file_list = [("TSQ.raw", ""), ("LCQ.raw", ""), ("LTQ.raw", ""),
-                 ("MAX.raw", ""), ("TSQsim.raw", ""), ("TSQ_pchan.RAW", ""),
-                 ("LTQ_wip.RAW", "LTQ_temp"), ("TSQ_temp.RAW", "TSQ_temp"),
-                 ("LTQ_pchan.RAW")]
+    file_list = [("TSQ.raw", ""), ("LCQ.raw", ""), ("LCQ_ercid.RAW",""),
+                 ("LTQ.raw", ""), ("MAX.raw", ""), ("TSQsim.raw", ""),
+                 ("TSQ_pchan.RAW", ""), ("LTQ_wip.RAW", "LTQ_temp"),
+                 ("TSQ_temp.RAW", "TSQ_temp"), ("LTQ_pchan.RAW", "")]
     for i in file_list:
         print(i)
         load_raw(*i)
